SHINKEN.TOOLS.TEST_AUTO.STRUCTURE = {
    "DEV"     : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.EXCLUDE,
        cancel_next    : true
    },
    "00000"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/main",
            "/main",
            "/main",
            "/main",
            "/main",
            "/main",
            "/main",
            "/main",
            "/main",
            "/main",
            "/sources/listener-test-auto?tab=tab-configuration",
            "/main",
            "/elements/elements?filter=type%3A%3D\"nouveau\"~name%3A!new&start=000&end=1000",
            "/elements/elements?filter=type%3A%3D\"nouveau\"~name%3A!new&start=000&end=1000",
            "/elements/working_area/hosts?filter=type%3A%3D\"nouveau\"~host_name%3A!new&save_in_staging=1&start=000&end=1000",
            "/elements/working_area/hosts?filter=type%3A%3D\"nouveau\"~host_name%3A!new&save_in_staging=1&start=000&end=1000",
            "/main",
            "/main",
            "/apply",
            "/main",
            "/main"
        ]
    },
    "00001"   : {
        phases         : 5,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000001"
    },
    "00002"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000002"
    },
    "00003"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000003"
    },
    "00004"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000004"
    },
    "00005"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000005"
    },
    "00006"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000006"
    },
    "00007"   : {
        phases         : 3,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000007"
    },
    "00008"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000008"
    },
    "00009"   : {
        phases         : 5,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000009"
    },
    "00010"   : {
        phases         : 4,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000010"
    },
    "00011"   : {
        phases         : 4,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000011"
    },
    "00012"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000012"
    },
    "00013"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000013"
    },
    "00014"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000014"
    },
    "00015"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000015"
    },
    "00016"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/contacts/00000000000000000000000000000016"
    },
    "00017"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000017"
    },
    "00018"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000018"
    },
    "00019"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        phases         : 2,
        address        : "/elements/hosts/00000000000000000000000000000019"
    },
    "00020"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        phases         : 13,
        address        : [
            "/elements/hosts/00000000000000000000000000000020",
            "/elements/hosts/00000000000000000000000000000020?tab=datas",
            "/elements/hosts/00000000000000000000000000000020?tab=datas",
            "/elements/hosts/00000000000000000000000000000020?tab=datas",
            "/elements/hosts/00000000000000000000000000000020?tab=datas",
            "/elements/hosts/00000000000000000000000000000020?tab=datas",
            "/elements/hosts/00000000000000000000000000000020?tab=datas",
            "/elements/hosts/00000000000000000000000000000020?tab=datas",
            "/elements/hosts/00000000000000000000000000000020?tab=datas",
            "/elements/hosts/00000000000000000000000000000020?tab=datas",
            "/elements/hosts/00000000000000000000000000000020?tab=datas",
            "/elements/hosts/00000000000000000000000000000020?tab=datas",
            "/elements/hosts/00000000000000000000000000000020?tab=datas"
        ]
    },
    "00021"   : {
        phases         : 3,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/serviceshosts/20000000000000000000000000000021"
    },
    "00022"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000022"
    },
    "00023"   : {
        phases         : 3,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000023"
    },
    "00024"   : {
        phases         : 3,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000024"
    },
    "00025"   : {
        phases         : 8,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosttpls/10000000000000000000000000000025"
    },
    "00026"   : {
        phases         : 4,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/serviceshosts/20000000000000000000000000000026"
    },
    "00027"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosttpls/10000000000000000000000000000027"
    },
    "00028"   : {
        phases         : 12,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000028"
    },
    "00029"   : {
        phases         : 8,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/sources/test_auto"
    },
    "00030"   : {
        phases         : 4,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000030"
    },
    "00031"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER,
            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER,
            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER,
            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER,
            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER,
            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER,
            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER,
            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER,
            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER + "?tab=tab-detail-last-run&filter=name:jo",
            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER,
            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER,
            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER,
            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER
        ]
    },
    "00032"   : {
        phases         : 2,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/add/timeperiod"
    },
    "00033"   : {
        phases         : 5,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000033"
    },
    "00034"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000034"
    },
    "00035"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000035"
    },
    "00036"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000036"
    },
    "00037"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000037"
    },
    "00038"   : {
        phases         : 6,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts/00000000000000000000000000000038"
    },
    "00039"   : {
        phases         : 3,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000039"
    },
    "00040"   : {
        phases         : 6,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000040"
    },
    "00041"   : {
        phases         : 3,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000041"
    },
    "00042"   : {
        phases         : 2,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000042"
    },
    "00043"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000043"
    },
    "00044"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000003",
        phases         : 3
    },
    "00045"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00046"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00047"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00048"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/clusters/06000000000000000000000000000000"
    },
    "00049"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/clustertpls/15000000000000000000000000000000"
    },
    "00050"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hostgroups/42000000000000000000000000000000"
    },
    "00051"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosttpls/12000000000000000000000000000000"
    },
    "00052"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/serviceshosts/22000000000000000000000000000000"
    },
    "00053"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/serviceshosttpls/21000000000000000000000000000003"
    },
    "00054"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/servicesclusters/24000000000000000000000000000000"
    },
    "00055"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/servicesclustertpls/23200000000000000000000000000001"
    },
    "00056"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/servicetpls/0eeb62945ae111e59fac080027f08538"
    },
    "00057"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/contacts/32000000000000000000000000000000"
    },
    "00058"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/contacttpls/36000000000000000000000000000000"
    },
    "00059"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/contactgroups/B2000000000000000000000000000000"
    },
    "00060"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/escalations/72000000000000000000000000000000"
    },
    "00061"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/notificationways/2ccd33005ae111e5842f080027f08538"
    },
    "00062"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/businessimpactmodulations/82000000000000000000000000000000"
    },
    "00063"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/macromodulations/92000000000000000000000000000000"
    },
    "00064"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/resultmodulations/A2000000000000000000000000000000"
    },
    "00065"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/commands/52000000000000000000000000000000"
    },
    "00066"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/timeperiods/62000000000000000000000000000000"
    },
    "00067"   : {
        phases         : 2,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00068"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00069"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00070"   : {
        phases         : 5,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/elements/hosts/00000000000000000000000000000001",
            "/elements/working_area/hosts?filter=sources:test_auto",
            "/elements/working_area/hosts?filter=sources:test_auto",
            "/elements/working_area/hosts?filter=sources:test_auto",
            "/elements/working_area/hosts?filter=sources:test_auto"
        ]
    },
    "00071"   : {
        phases         : 2,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00072"   : {
        phases         : 2,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00073"   : {
        phases         : 2,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00074"   : {
        phases         : 2,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00075"   : {
        phases         : 2,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00076"   : {
        phases         : 2,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00077"   : {
        phases         : 2,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00078"   : {
        phases         : 2,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00079"   : {
        phases         : 2,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00080"   : {
        phases         : 2,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00081"   : {
        phases         : 1,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/main"
    },
    "00082"   : {
        phases         : 10,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00083"   : {
        phases         : 10,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts?filter=sources:test_auto"
    },
    "00084"   : {
        phases         : 2,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/elements?filter=name%3Atest_auto_list_filter~sources%3Atest_auto"
    },
    "00085"   : {
        phases         : 3,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosttpls?filter=name%3Atest_auto_list_filter~sources:test_auto"
    },
    "00086"   : {
        phases         : 20,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=host_name%3Atest_auto_list_filter~sources:test_auto"
    },
    "00087"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000087"
    },
    "00088"   : {
        phases         : 6,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000088"
    },
    "00089"   : {
        phases         : 2,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/resultmodulations/00000000000000000000000000000089"
    },
    "00090"   : {
        phases         : 2,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/timeperiods/00000000000000000000000000000090"
    },
    "00091"   : {
        phases         : 5,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/timeperiods/00000000000000000000000000000091"
    },
    "00092"   : {
        phases         : 2,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00093"   : {
        phases         : 8,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00094"   : {
        phases         : 1,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/servicetpls"
    },
    "00095"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/main",
        not_done       : true
    },
    "00096"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/main",
        not_done       : true
    },
    "00097"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/main",
        not_done       : true
    },
    "00098"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/main",
        not_done       : true
    },
    "00099"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/main",
        not_done       : true
    },
    "00100"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/timeperiods"
    },
    "00101"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/commands"
    },
    "00102"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/resultmodulations"
    },
    "00103"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/macromodulations"
    },
    "00104"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/businessimpactmodulations"
    },
    "00105"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/notificationways"
    },
    "00106"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/escalations"
    },
    "00107"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/contacttpls"
    },
    "00108"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/contactgroups"
    },
    "00109"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/contacts"
    },
    "00110"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/servicetpls"
    },
    "00111"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/servicesclustertpls"
    },
    "00112"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/servicesclusters"
    },
    "00113"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/serviceshosttpls"
    },
    "00114"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/serviceshosts"
    },
    "00115"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosttpls"
    },
    "00116"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hostgroups"
    },
    "00117"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/clustertpls"
    },
    "00118"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/clusters"
    },
    "00119"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts"
    },
    "00120"   : {
        phases         : 4,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/clusters/06000000000000000000000000000000"
    },
    "00121"   : {
        phases         : 4,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/03000000000000000000000000000000"
    },
    "00122"   : {
        phases         : 10,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/03000000000000000000000000000000"
    },
    "00123"   : {
        phases         : 30,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00124"   : {
        phases         : 10,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000124"
    },
    "00125"   : {
        phases         : 6,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000124"
    },
    "00126"   : {
        phases         : 30,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00127"   : {
        phases         : 1,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/serviceshosts?filter=sources"
    },
    "00128"   : {
        phases         : 1,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/timeperiods"
    },
    "00129"   : {
        phases         : 3,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00130"   : {
        phases         : 3,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto"
    },
    "00131"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/serviceshosts/22000000000000000000000000000001"
    },
    "00132"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts",
        phases         : 4
    },
    "00133"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts",
        phases         : 4
    },
    "00134"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts",
        phases         : 2
    },
    "00135"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000135",
        phases         : 2
    },
    "00136"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/hosts/03000000000000000000000000000000",
            "/elements/hosts/03000000000000000000000000000000",
            "/elements/hosts/03000000000000000000000000000000",
            "/main"
        ]
    },
    "00137"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/03000000000000000000000000000000"
    },
    "00138"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/serviceshosts/23000000000000000000000000000000",
            "/main"
        ]
    },
    "00139"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/elements/hosts/00000000000000000000000000000003",
            "/elements/hosts/00000000000000000000000000000003"
        ]
    },
    "00140"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000001",
        phases         : 5
    },
    "00141"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts/00000000000000000000000000000141",
        phases         : 4
    },
    "00142"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/hosts/00000000000000000000000000000142?new=1",
            "/elements/hosts/00000000000000000000000000000142",
            "/elements/serviceshosts/20000000000000000000000000000142?new=1",
            "/elements/serviceshosts/20000000000000000000000000000142",
            "/main",
            "/elements/serviceshosts/20000000000000000000000000000142?new=1",
            "/elements/serviceshosts/20000000000000000000000000000142",
            "/elements/hosts/00000000000000000000000000000142?new=1",
            "/elements/hosts/00000000000000000000000000000142"
        ]
    },
    "00143"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/hosts/00000000000000000000000000000143?new=1",
            "/elements/hosts/00000000000000000000000000000143",
            "/elements/serviceshosts/20000000000000000000000000000143?new=1",
            "/elements/serviceshosts/20000000000000000000000000000143",
            "/main",
            "/elements/serviceshosts/20000000000000000000000000000143?new=1",
            "/elements/serviceshosts/20000000000000000000000000000143",
            "/elements/hosts/00000000000000000000000000000143?new=1",
            "/elements/hosts/00000000000000000000000000000143"
        ]
    },
    "00144"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/hosts/00000000000000000000000000000144?new=1",
            "/elements/hosts/00000000000000000000000000000144",
            "/elements/serviceshosts/20000000000000000000000000000144?new=1",
            "/elements/serviceshosts/20000000000000000000000000000144",
            "/elements/hosts/00000000000000000000000000000144",
            "/elements/hosts/00000000000000000000000000000144",
            "/main",
            "/elements/hosts/00000000000000000000000000000144?new=1",
            "/elements/hosts/00000000000000000000000000000144",
            "/elements/serviceshosts/20000000000000000000000000000144?new=1",
            "/elements/serviceshosts/20000000000000000000000000000144",
            "/elements/working_area/hosts",
            "/elements/working_area/hosts"
        ]
    },
    "00145"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/hosts/00000000000000000000000000000145?new=1",
            "/elements/hosts/00000000000000000000000000000145",
            "/elements/hosttpls/10000000000000000000000000000145?new=1",
            "/elements/hosttpls/10000000000000000000000000000145",
            "/elements/hosttpls/10100000000000000000000000000145?new=1",
            "/elements/hosttpls/10100000000000000000000000000145",
            "/elements/serviceshosttpls/20000000000000000000000000000145?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000145",
            "/elements/hosttpls/10100000000000000000000000000145",
            "/elements/hosttpls/10100000000000000000000000000145",
            "/elements/hosts/00000000000000000000000000000145"
        ]
    },
    "00146"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/hosts/00000000000000000000000000000146?new=1",
            "/elements/hosts/00000000000000000000000000000146",
            "/elements/hosttpls/10000000000000000000000000000146?new=1",
            "/elements/hosttpls/10000000000000000000000000000146",
            "/elements/serviceshosttpls/20000000000000000000000000000146?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000146",
            "/elements/hosttpls/10000000000000000000000000000146",
            "/elements/hosttpls/10000000000000000000000000000146",
            "/elements/hosts/00000000000000000000000000000146",
            "/main",
            "/elements/hosts/00000000000000000000000000000146?new=1",
            "/elements/hosts/00000000000000000000000000000146",
            "/elements/hosttpls/10000000000000000000000000000146?new=1",
            "/elements/hosttpls/10000000000000000000000000000146",
            "/elements/serviceshosttpls/20000000000000000000000000000146?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000146",
            "/elements/hosttpls"
        ]
    },
    "00147"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000147"
    },
    "00148"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/hosts/00000000000000000000000000000146?new=1",
            "/elements/hosts/00000000000000000000000000000146",
            "/elements/hosttpls/10000000000000000000000000000146?new=1",
            "/elements/hosttpls/10000000000000000000000000000146",
            "/elements/serviceshosttpls/20000000000000000000000000000146?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000146",
            "/elements/hosts/00000000000000000000000000000146",
            "/elements/hosts/00000000000000000000000000000146",
            "/elements/hosts/00000000000000000000000000000146",
            "/main",
            "/elements/hosts/00000000000000000000000000000146?new=1",
            "/elements/hosts/00000000000000000000000000000146",
            "/elements/hosttpls/10000000000000000000000000000146?new=1",
            "/elements/hosttpls/10000000000000000000000000000146",
            "/elements/serviceshosttpls/20000000000000000000000000000146?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000146",
            "/elements/working_area/hosts"
        ]
    },
    "00149"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/hosts/00000000000000000000000000000149?new=1",
            "/elements/hosts/00000000000000000000000000000149",
            "/elements/hosttpls/10000000000000000000000000000149?new=1",
            "/elements/hosttpls/10000000000000000000000000000149",
            "/elements/serviceshosts/20000000000000000000000000000149?new=1",
            "/elements/serviceshosts/20000000000000000000000000000149",
            "/elements/hosttpls/10000000000000000000000000000149",
            "/elements/hosttpls/10000000000000000000000000000149",
            "/elements/hosts/00000000000000000000000000000149",
            "/main",
            "/elements/hosts/00000000000000000000000000000149?new=1",
            "/elements/hosts/00000000000000000000000000000149",
            "/elements/hosttpls/10000000000000000000000000000149?new=1",
            "/elements/hosttpls/10000000000000000000000000000149",
            "/elements/serviceshosts/20000000000000000000000000000149?new=1",
            "/elements/serviceshosts/20000000000000000000000000000149",
            "/elements/hosttpls"
        ]
    },
    "00150"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/hosts/00000000000000000000000000000150?new=1",
            "/elements/hosts/00000000000000000000000000000150",
            "/elements/hosttpls/10000000000000000000000000000150?new=1",
            "/elements/hosttpls/10000000000000000000000000000150",
            "/elements/hosttpls/10100000000000000000000000000150?new=1",
            "/elements/hosttpls/10100000000000000000000000000150",
            "/elements/serviceshosttpls/20000000000000000000000000000150?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000150",
            "/elements/hosttpls/10000000000000000000000000000150",
            "/elements/hosttpls/10000000000000000000000000000150",
            "/elements/hosts/00000000000000000000000000000150",
            "/main",
            "/elements/hosts/00000000000000000000000000000150?new=1",
            "/elements/hosts/00000000000000000000000000000150",
            "/elements/hosttpls/10000000000000000000000000000150?new=1",
            "/elements/hosttpls/10000000000000000000000000000150",
            "/elements/hosttpls/10100000000000000000000000000150?new=1",
            "/elements/hosttpls/10100000000000000000000000000150",
            "/elements/serviceshosttpls/20000000000000000000000000000150?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000150",
            "/elements/hosttpls"
        ]
    },
    "00151"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/hosts/00000000000000000000000000000151?new=1",
            "/elements/hosts/00000000000000000000000000000151",
            "/elements/hosttpls/10000000000000000000000000000151?new=1",
            "/elements/hosttpls/10000000000000000000000000000151",
            "/elements/hosttpls/10100000000000000000000000000151?new=1",
            "/elements/hosttpls/10100000000000000000000000000151",
            "/elements/serviceshosttpls/20000000000000000000000000000151?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000151",
            "/elements/hosttpls/10100000000000000000000000000151",
            "/elements/hosttpls/10100000000000000000000000000151",
            "/elements/hosts/00000000000000000000000000000151",
            "/main",
            "/elements/hosts/00000000000000000000000000000151?new=1",
            "/elements/hosts/00000000000000000000000000000151",
            "/elements/hosttpls/10000000000000000000000000000151?new=1",
            "/elements/hosttpls/10000000000000000000000000000151",
            "/elements/hosttpls/10100000000000000000000000000151?new=1",
            "/elements/hosttpls/10100000000000000000000000000151",
            "/elements/serviceshosttpls/20000000000000000000000000000151?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000151",
            "/elements/hosttpls"
        ]
    },
    "00152"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/hosts/00000000000000000000000000000152?new=1",
            "/elements/hosts/00000000000000000000000000000152",
            "/elements/hosttpls/10000000000000000000000000000152?new=1",
            "/elements/hosttpls/10000000000000000000000000000152",
            "/elements/hosttpls/10100000000000000000000000000152?new=1",
            "/elements/hosttpls/10100000000000000000000000000152",
            "/elements/hosttpls/10200000000000000000000000000152?new=1",
            "/elements/hosttpls/10200000000000000000000000000152",
            "/elements/serviceshosttpls/20000000000000000000000000000152?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000152",
            "/elements/hosttpls/10200000000000000000000000000152",
            "/elements/hosttpls/10200000000000000000000000000152",
            "/elements/hosts/00000000000000000000000000000152",
            "/main",
            "/elements/hosts/00000000000000000000000000000152?new=1",
            "/elements/hosts/00000000000000000000000000000152",
            "/elements/hosttpls/10000000000000000000000000000152?new=1",
            "/elements/hosttpls/10000000000000000000000000000152",
            "/elements/hosttpls/10100000000000000000000000000152?new=1",
            "/elements/hosttpls/10100000000000000000000000000152",
            "/elements/hosttpls/10200000000000000000000000000152?new=1",
            "/elements/hosttpls/10200000000000000000000000000152",
            "/elements/serviceshosttpls/20000000000000000000000000000152?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000152",
            "/elements/hosttpls",
            "/elements/hosts/00000000000000000000000000000152"
        ]
    },
    "00153"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/hosts/00000000000000000000000000000153?new=1",
            "/elements/hosts/00000000000000000000000000000153",
            "/elements/hosttpls/10000000000000000000000000000153?new=1",
            "/elements/hosttpls/10000000000000000000000000000153",
            "/elements/hosttpls/10100000000000000000000000000153?new=1",
            "/elements/hosttpls/10100000000000000000000000000153",
            "/elements/hosttpls/10200000000000000000000000000153?new=1",
            "/elements/hosttpls/10200000000000000000000000000153",
            "/elements/serviceshosttpls/20000000000000000000000000000153?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000153",
            "/elements/hosttpls/10100000000000000000000000000153",
            "/elements/hosttpls/10100000000000000000000000000153",
            "/elements/hosts/00000000000000000000000000000153",
            "/main",
            "/elements/hosts/00000000000000000000000000000153?new=1",
            "/elements/hosts/00000000000000000000000000000153",
            "/elements/hosttpls/10000000000000000000000000000153?new=1",
            "/elements/hosttpls/10000000000000000000000000000153",
            "/elements/hosttpls/10100000000000000000000000000153?new=1",
            "/elements/hosttpls/10100000000000000000000000000153",
            "/elements/hosttpls/10200000000000000000000000000153?new=1",
            "/elements/hosttpls/10200000000000000000000000000153",
            "/elements/serviceshosttpls/20000000000000000000000000000153?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000153",
            "/elements/hosttpls",
            "/elements/hosts/00000000000000000000000000000153"
        ]
    },
    "00154"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/hosts/00000000000000000000000000000154?new=1",
            "/elements/hosts/00000000000000000000000000000154",
            "/elements/hosttpls/10000000000000000000000000000154?new=1",
            "/elements/hosttpls/10000000000000000000000000000154",
            "/elements/hosttpls/10100000000000000000000000000154?new=1",
            "/elements/hosttpls/10100000000000000000000000000154",
            "/elements/hosttpls/10200000000000000000000000000154?new=1",
            "/elements/hosttpls/10200000000000000000000000000154",
            "/elements/serviceshosttpls/20000000000000000000000000000154?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000154",
            "/elements/hosttpls/10000000000000000000000000000154",
            "/elements/hosttpls/10000000000000000000000000000154",
            "/elements/hosts/00000000000000000000000000000154",
            "/main",
            "/elements/hosts/00000000000000000000000000000154?new=1",
            "/elements/hosts/00000000000000000000000000000154",
            "/elements/hosttpls/10000000000000000000000000000154?new=1",
            "/elements/hosttpls/10000000000000000000000000000154",
            "/elements/hosttpls/10100000000000000000000000000154?new=1",
            "/elements/hosttpls/10100000000000000000000000000154",
            "/elements/hosttpls/10200000000000000000000000000154?new=1",
            "/elements/hosttpls/10200000000000000000000000000154",
            "/elements/serviceshosttpls/20000000000000000000000000000154?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000154",
            "/elements/hosttpls",
            "/elements/hosts/00000000000000000000000000000154"
        ]
    },
    "00155"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/hosts/00000000000000000000000000000155?new=1",
            "/elements/hosts/00000000000000000000000000000155",
            "/elements/hosttpls/10000000000000000000000000000155?new=1",
            "/elements/hosttpls/10000000000000000000000000000155",
            "/elements/hosttpls/10100000000000000000000000000155?new=1",
            "/elements/hosttpls/10100000000000000000000000000155",
            "/elements/hosttpls/10200000000000000000000000000155?new=1",
            "/elements/hosttpls/10200000000000000000000000000155",
            "/elements/serviceshosttpls/20000000000000000000000000000155?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000155",
            "/elements/hosttpls/10200000000000000000000000000155",
            "/elements/hosttpls/10200000000000000000000000000155",
            "/elements/hosts/00000000000000000000000000000155",
            "/main",
            "/elements/hosts/00000000000000000000000000000155?new=1",
            "/elements/hosts/00000000000000000000000000000155",
            "/elements/hosttpls/10000000000000000000000000000155?new=1",
            "/elements/hosttpls/10000000000000000000000000000155",
            "/elements/hosttpls/10100000000000000000000000000155?new=1",
            "/elements/hosttpls/10100000000000000000000000000155",
            "/elements/hosttpls/10200000000000000000000000000155?new=1",
            "/elements/hosttpls/10200000000000000000000000000155",
            "/elements/serviceshosttpls/20000000000000000000000000000155?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000155",
            "/elements/hosttpls",
            "/elements/hosts/00000000000000000000000000000155"
        ]
    },
    "00156"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/hosts/00000000000000000000000000000156?new=1",
            "/elements/hosts/00000000000000000000000000000156",
            "/elements/hosttpls/10000000000000000000000000000156?new=1",
            "/elements/hosttpls/10000000000000000000000000000156",
            "/elements/hosttpls/10100000000000000000000000000156?new=1",
            "/elements/hosttpls/10100000000000000000000000000156",
            "/elements/hosttpls/10200000000000000000000000000156?new=1",
            "/elements/hosttpls/10200000000000000000000000000156",
            "/elements/serviceshosttpls/20000000000000000000000000000156?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000156",
            "/elements/hosttpls/10200000000000000000000000000156",
            "/elements/hosttpls/10200000000000000000000000000156",
            "/elements/hosts/00000000000000000000000000000156",
            "/main",
            "/elements/hosts/00000000000000000000000000000156?new=1",
            "/elements/hosts/00000000000000000000000000000156",
            "/elements/hosttpls/10000000000000000000000000000156?new=1",
            "/elements/hosttpls/10000000000000000000000000000156",
            "/elements/hosttpls/10100000000000000000000000000156?new=1",
            "/elements/hosttpls/10100000000000000000000000000156",
            "/elements/hosttpls/10200000000000000000000000000156?new=1",
            "/elements/hosttpls/10200000000000000000000000000156",
            "/elements/serviceshosttpls/20000000000000000000000000000156?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000156",
            "/elements/hosttpls",
            "/elements/hosts/00000000000000000000000000000156"
        ]
    },
    "00157"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/hosts/00000000000000000000000000000157?new=1",
            "/elements/hosts/00000000000000000000000000000157",
            "/elements/hosttpls/10000000000000000000000000000157?new=1",
            "/elements/hosttpls/10000000000000000000000000000157",
            "/elements/hosttpls/10100000000000000000000000000157?new=1",
            "/elements/hosttpls/10100000000000000000000000000157",
            "/elements/hosttpls/10200000000000000000000000000157?new=1",
            "/elements/hosttpls/10200000000000000000000000000157",
            "/elements/serviceshosttpls/20000000000000000000000000000157?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000157",
            "/elements/hosttpls/10000000000000000000000000000157",
            "/elements/hosttpls/10000000000000000000000000000157",
            "/elements/hosts/00000000000000000000000000000157",
            "/main",
            "/elements/hosts/00000000000000000000000000000157?new=1",
            "/elements/hosts/00000000000000000000000000000157",
            "/elements/hosttpls/10000000000000000000000000000157?new=1",
            "/elements/hosttpls/10000000000000000000000000000157",
            "/elements/hosttpls/10100000000000000000000000000157?new=1",
            "/elements/hosttpls/10100000000000000000000000000157",
            "/elements/hosttpls/10200000000000000000000000000157?new=1",
            "/elements/hosttpls/10200000000000000000000000000157",
            "/elements/serviceshosttpls/20000000000000000000000000000157?new=1",
            "/elements/serviceshosttpls/20000000000000000000000000000157",
            "/elements/hosttpls",
            "/elements/hosts/00000000000000000000000000000157",
            "/apply",
            "/apply"
            //"http://127.0.0.1:9000/#/list/all"
        ]
    },
    "00158"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        :
            [
                "/sources/server-analyzer?tab=tab-configuration",
                "/sources/server-analyzer?tab=tab-configuration",
                "/sources/server-analyzer?tab=tab-configuration",
                "/sources/server-analyzer?tab=tab-configuration",
                "/sources/server-analyzer?tab=tab-configuration"
            ]
    },
    "00159"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/sources/test_auto?tab=tab-configuration"
    },
    "00160"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/sources/listener-shinken?tab=tab-configuration"
    },
    "00161"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/sources/cfg-file-shinken?tab=tab-configuration"
    },
    "00162"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/sources/discovery?tab=tab-configuration"
    },
    "00163"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/elements?filter=type%3A%3D\"nouveau\"~name%3A!new&start=000&end=1000",
            "/elements/elements?filter=type%3A%3D\"nouveau\"~name%3A!new&start=000&end=1000",
            "/elements/working_area/hosts/00000000000000000000000000000163?new=1",
            "/elements/working_area/hosts/00000000000000000000000000000163",
            "/elements/working_area/hosts/00000000000000000000000000000163",
            "/elements/hosts/00000000000000000000000000000163",
            "/elements/hosts/00000000000000000000000000000163",
            "/elements/working_area/hosts/00000000000000000000000000000163",
            "/elements/hosts/00000000000000000000000000000163",
            "/elements/hosts/00000000000000000000000000000163",
            "/elements/working_area/hosts/00000000000000000000000000000163",
            "/elements/working_area/hosts/00000000000000000000000000000163",
            "/elements/hosts/00000000000000000000000000000163"
        ]
    },
    "00164"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/elements/working_area/hosts/00000000000000000000000000000164",
            "/elements/working_area/hosts/00000000000000000000000000000164",
            "/elements/working_area/hosts/00010000000000000000000000000164",
            "/elements/working_area/hosts/00010000000000000000000000000164",
            "/elements/working_area/hosts/00000000000000000000000000000164",
            "/elements/working_area/hosts/00010000000000000000000000000164",
            "/elements/working_area/hosts/00010000000000000000000000000164",
            "/elements/working_area/hosts/00000000000000000000000000000164",
            "/elements/hosts/00010000000000000000000000000164",
            "/elements/hosts/00010000000000000000000000000164",
            "/elements/working_area/hosts/00000000000000000000000000000164",
            "/elements/working_area/hosts/00030000000000000000000000000164",
            "/elements/working_area/hosts/00030000000000000000000000000164",
            "/elements/working_area/hosts/00000000000000000000000000000164",
            "/elements/working_area/hosts/00000000000000000000000000000164",
            "/elements/working_area/hosts/00000000000000000000000000000164",
            "/elements/working_area/hosts/00050000000000000000000000000164",
            "/elements/working_area/hosts/00050000000000000000000000000164",
            "/elements/working_area/hosts/00000000000000000000000000000164",
            "/elements/working_area/hosts/00000000000000000000000000000164",
            "/elements/working_area/hosts/00020000000000000000000000000164?new=1",
            "/elements/working_area/hosts/00020000000000000000000000000164",
            "/elements/working_area/hosts/00000000000000000000000000000164",
            "/elements/working_area/hosts/00010000000000000000000000000164",
            "/elements/working_area/hosts/00010000000000000000000000000164",
            "/elements/working_area/hosts/00000000000000000000000000000164"
        ]
    },
    "00165"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/working_area/hosts/00000000000000000000000000000165?new=1",
            "/elements/add/working_area/hosts",
            "/elements/working_area/hosts/00000000000000000000000000000165?new=1",
            "/elements/working_area/hosts/00000000000000000000000000000165",
            "/elements/add/working_area/hosts"
        ]
    },
    "00166"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/elements/working_area/hosts/00000000000000000000000000000166",
            "/elements/working_area/hosts/00000000000000000000000000000166",
            "/elements/working_area/hosts/00000000000000000000000000000166",
            "/elements/working_area/hosts/00000000000000000000000000000166",
            "/elements/working_area/hosts?filter=host_name%3A00166_test_auto",
            "/elements/working_area/hosts?filter=host_name%3A00166_test_auto",
            "/elements/working_area/hosts?filter=host_name%3A00166_test_auto"
        ]
    },
    "00167"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts"
    },
    "00168"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts"
    },
    "00169"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/elements/working_area/hosts",
            "/elements/working_area/hosts"
        ]
    },
    "00170"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/elements/working_area/hosts",
            "/elements/working_area/hosts"
        ]
    },
    "00171"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/elements/working_area/hosts/00000000000000000000000000000001",
            "/elements/working_area/hosts/00000000000000000000000000000001",
            "/elements/working_area/hosts/00000000000000000000000000000001"
        ]
    },
    "00172"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_VMWARE,
            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_VMWARE,
            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_VMWARE,
            "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_VMWARE
        ]
    },
    "00173"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : 7767,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/service-weather/00000000000000000000000000000001",
            "/service-weather/00000000000000000000000000000001",
            "/service-weather/00000000000000000000000000000001",
            "/service-weather/00000000000000000000000000000001",
            "/service-weather/00000000000000000000000000000001"
        ],
        subject        : "service_weather"
    },
    "00174"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        phases         : 1,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts"
    },
    "00175"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : 7767,
        phases         : 47,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/service-weather/00000000000000000000000000000001",
        subject        : "service_weather"
    },
    "00176"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : 7767,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/service-weather/00000000000000000000000000000001",
            "/service-weather/00000000000000000000000000000001"
        ],
        subject        : "service_weather"
    },
    "00177"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/elements/clusters?list_extra_columns=visualisation_name",
            "/elements/clusters?list_extra_columns=visualisation_name",
            "/elements/clusters?list_extra_columns=visualisation_name",
            "/elements/clusters?list_extra_columns=visualisation_name",
            "/elements/clusters?list_extra_columns=visualisation_name",
            "/elements/clusters?list_extra_columns=visualisation_name",
            "/elements/clusters?list_extra_columns=visualisation_name"
        ]
    },
    "00178"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000011"
    },
    "00179"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/hosts/00000000000000000000000000000179",
            "/main"
        ]
    },
    "00180"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/elements/hosts/00000000000000000000000000000180",
            "/elements/hosts/00000000000000000000000000000180",
            "/elements/working_area/hosts?filter=type:\"Différence\"",
            "/elements/working_area/hosts/00000000000000000000000000000180?tab=changes"
        ]
    },
    "00181"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        phases         : 2,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/serviceshosttpls/20010000000000000000000000000000"
    },
    "00182"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        phases         : 9,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/working_area/hosts/00000000000000000000000000000182?new=1",
            "/elements/working_area/hosts/00000000000000000000000000000182",
            "/elements/add/working_area/hosts",
            "/elements/add/working_area/hosts",
            "/main",
            "/main",
            "/main",
            "/elements/add/working_area/hosts"
        ]
    },
    "00183"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/main",
            "/main",
            "/main",
            "/main",
            "/main",
            "/main"
        ]
    },
    "00184"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/elements/working_area/hosts",
            "/elements/working_area/hosts",
            "/elements/working_area/hosts",
            "/elements/working_area/hosts",
            "/elements/working_area/hosts",
            "/elements/working_area/hosts",
            "/elements/working_area/hosts"
        ]
    },
    "00185"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : 7767,
        phases         : 5,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/service-weather/00000000000000000000000000000001",
        subject        : "service_weather"
    },
    "00186"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : 7767,
        phases         : 1,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/service-weather/00000000000000000000000000000001",
        subject        : "service_weather"
    },
    "00187"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/apply"
        ]
    },
    "00188"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        phases         : 1,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts/00000000000000000000000000000188?new=1"
    },
    "00189"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/elements/hosts/00000000000000000000000000000001",
            "/elements/hosts/00000000000000000000000000000001",
            "/apply",
            "/elements/hosts/00000000000000000000000000000001",
            "/elements/hosts",
            "/apply",
            "/main"
        ]
    },
    "00190"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        phases         : 1,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/apply"
    },
    "00191"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/sources/discovery?tab=tab-network-scan&source-name=discovery&conf-id=new",
            "/sources/discovery?tab=tab-network-scan",
            "/main"
        ]
    },
    "00192"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        phases         : 6,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000001"
        
    },
    "00193"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        phases         : 4,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000001",
        subject        : "user-rights,synchronization"
    },
    "00194"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : 7767,
        phases         : 3,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/service-weather/00000000000000000000000000000001",
        subject        : "service_weather"
    },
    "00195"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : 7767,
        phases         : 10,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/static/ui/index.html",
        subject        : "navigation"
    },
    "00196"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : 7767,
        phases         : 4,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/static/ui/index.html",
        subject        : "reporting,navigation"
    },
    "00197"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : [7766, 7767, 7766, 7767, 7766],
        phases         : 5,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/static/ui/index.html",
            "/main",
            "/static/ui/index.html",
            "/main"
        ],
        subject        : "licence"
    },
    "00198"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : 7766,
        phases         : 2,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/sources/syncui?filter=name:00001_test_auto",
            "/sources/test_auto?filter=name:00001_test_auto"
        ],
        subject        : "source"
    },
    "00199"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : [7766, 7767, 7767, 7767, 7767, 7767, 7766, 7767],
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/static/ui/index.html",
            "/static/ui/index.html",
            "/static/ui/index.html",
            "/static/ui/index.html",
            "/static/ui/index.html",
            "/main",
            "/static/ui/index.html"
        ],
        subject        : "ui_view_manager"
    },
    "00200"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : [7766, 7767],
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/static/ui/index.html"
        ],
        subject        : "ui_view_manager"
    },
    "00201"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : 7767,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        :
            "/service-weather/00000000000000000000000000000001",
        subject        : "service_weather"
    },
    "00202"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        phases         : 1,
        port           : 7767,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/static/ui/index.html",
        subject        : "ui_visualisation_list"
    },
    "00203"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : [7766, 7767],
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/static/ui/index.html"
        ],
        subject        : "shinken-healthcheck"
    },
    "00204"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/sources/server-analyzer?tab=tab-configuration",
            "/sources/server-analyzer?tab=tab-configuration",
            "/sources/server-analyzer?tab=tab-network-scan",
            "/sources/server-analyzer?tab=tab-network-scan",
            "/analyzers/server-analyzer?tab=tab-analyze-jobs-in-progress"
        ]
    },
    "00205"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        phases         : 3,
        port           : [7767, 7766, 7766],
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/static/ui/index.html",
            "/elements/hosts/00000000000000000000000000000205?tab=checks",
            "/elements/hosts/00000000000000000000000000000205?tab=checks"
        ],
        subject        : "service_weather,try_check"
    },
    "00206"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        phases         : 2,
        port           : [7766, 7766],
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/elements/working_area/hosts/00000000000000000000000000000008",
            "/elements/working_area/hosts/00000000000000000000000000000008"
        ],
        subject        : "try_check,DFE"
    },
    "00207"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/elements/hosttpls/12000000000000000000000000000000",
            "/elements/hosttpls/12000000000000000000000000000000",
            "/elements/hosttpls/12000000000000000000000000000001",
            "/elements/hosttpls/12000000000000000000000000000001",
            "/elements/hosts/00000000000000000000000000000001",
            "/elements/hosts/00000000000000000000000000000001",
            "/elements/hostgroups/42000000000000000000000000000000",
            "/elements/hostgroups/42000000000000000000000000000000",
            "/elements/working_area/hosts/00000000000000000000000000000001"
        ]
    },
    "00208"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : 7767,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/service-weather/00000000000000000000000000000001",
        subject        : "service_weather"
    },
    "00209"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : 7767,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/service-weather/00000000000000000000000000000001",
        subject        : "service_weather"
    },
    "00210"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        phases         : 1,
        port           : 7767,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/static/ui/index.html",
        subject        : "ui_visualisation_list"
    },
    "00211"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/elements/working_area/hosts?filter=host_name:211",
            "/elements/working_area/hosts?filter=host_name:211",
            "/elements/working_area/hosts?filter=host_name:211",
            "/elements/working_area/hosts?filter=host_name:211",
            "/elements/working_area/hosts?filter=host_name:211",
            "/apply"
        ],
        subject        : "mass_actions,clone,apply_in_production"
    },
    "00212"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/elements/working_area/hosts/00000000000000000000000000000001"
        ],
        subject        : "try_check"
    },
    "00213"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/sources/test_auto?tab=tab-summary-old-run"
        ],
        subject        : "source"
    },
    "00214"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/sources/server-analyzer?tab=tab-analyzer-template-mapping",
            "/sources/server-analyzer?tab=tab-analyzer-template-mapping"
        ],
        subject        : "fail_xss"
    },
    "00215"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : [7766, 7766, 7766, 7767, 7766, 7766, 7766, 7767],
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/elements/hosts/00000000000000000000000000000003",
            "/apply",
            "/apply",
            "/static/ui/index.html#/list/all"
        ],
        address_window : [
            "/elements/hosts/00000000000000000000000000000003",
            "/apply",
            "/apply",
            "/static/ui/index.html"
        ],
        port_window    : [7766, 7766, 7766, 7766],
        subject        : "ui_visualisation,list_filter"
    },
    "00216"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : 7766,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/elements/working_area/hosts",
            "/elements/working_area/hosts",
            "/elements/working_area/hosts",
            "/elements/working_area/hosts",
            "/elements/working_area/hosts"
        ],
        subject        : "configuration_list"
    },
    "00217"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : [7766, 7766, 7766, 7766, 7767, 7766, 7767, 7766, 7766, 7766, 7767, 7766, 7767, 7766],
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/hosts/00000000000000000000000000000001",
            "/elements/hosts/00000000000000000000000000000001",
            "/elements/hosts/00000000000000000000000000000001",
            "/service-weather/00000000000000000000000000000001",
            "/main",
            "/service-weather/00000000000000000000000000000001",
            "/main",
            "/elements/hosts/00000000000000000000000000000001",
            "/elements/hosts/00000000000000000000000000000001",
            "/service-weather/00000000000000000000000000000001",
            "/main",
            "/service-weather/00000000000000000000000000000001",
            "/main"
        ],
        subject        : "user_rights,service_weather"
    },
    "00218"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000001",
        subject        : "try_check"
    },
    "00219"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : 7767,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/static/ui/index.html",
        subject        : "service_weather"
    },
    "00220"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : 7766,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/hosts/00000000000000000000000000000003",
        subject        : "counters"
    },
    "00221"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/apply"
        ],
        subject        : "scheduler"
    },
    "00222"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : 7767,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/static/ui/index.html",
        subject        : "ui-visualisation,help"
    },
    "00223"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/main",
        subject        : "synchronizer"
    },
    "00224"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/main",
        subject        : "synchronizer"
    },
    "00225"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/main",
        subject        : "log_broker"
    },
    "00226"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/apply",
            "/apply",
            "/elements/hosts/00000000000000000000000000000002",
            "/elements/hosts/00000000000000000000000000000002",
            "/apply",
            "/apply",
            "/apply",
            "/apply",
            "/elements/hosts/00000000000000000000000000000002",
            "/elements/hosts/00000000000000000000000000000002",
            "/apply"
        ],
        subject        : "apply_in_production"
    },
    "00227"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : [7766, 7766, 7766, 7766, 7766, 7766, 7766, 7767, 7766, 7766, 7766, 7767, 7767],
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/main",
            "/apply",
            "/apply",
            "/main",
            "/apply",
            "/apply",
            "/static/ui/index.html#/dashboard/dash-00000000000000000000000000000227",
            "/main",
            "/apply",
            "/apply",
            "/static/ui/index.html#/dashboard/dash-00000000000000000000000000000227/detail/00000000000000000000000000000227/manage",
            "/static/ui/index.html#/dashboard/dash-00000000000000000000000000000227"
        ],
        subject        : "sla"
    },
    "00228"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : ["/main", "/elements/add/contact"],
        subject        : "shinken_protected_fields"
    },
    "00229"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/main",
        subject        : "sources"
    },
    "00230"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/add/working_area/hosts",
            "/elements/add/cluster",
            "/elements/add/hosttpl",
            "/elements/add/clustertpl",
            "/elements/working_area/hosts?filter=sources:test_auto",
            "/main"
        ],
        subject        : "sources"
    },
    "00231"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : 7767,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/static/ui/index.html#/service_weather/00000000000000000000000000000001",
            "/static/ui/index.html#/service_weather/00000000000000000000000000000001"
        ],
        subject        : "service_weather"
    },
    "00232"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main"
        ],
        subject        : "Scheduler"
    },
    "00233"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : [
            "/main",
            "/elements/hosts/03000000000000000000000000000000", // HOST
            "/elements/hosttpls/12000000000000000000000000000000", // HOST TPL
            "/elements/clusters/06000000000000000000000000000000", // CLUSTER
            "/elements/clustertpls/15000000000000000000000000000000", // CLUSTER TPL
            "/elements/serviceshosts/22000000000000000000000000000000", // CHECK HOST
            "/elements/serviceshosttpls/20010000000000000000000000000000", // CHECK HOST TPL
            "/elements/servicesclusters/24000000000000000000000000000000", // CHECK CLUSTER
            "/elements/servicesclustertpls/23200000000000000000000000000001", // CHECK CLUSTER TPL
            "/elements/servicetpls/20A00000000000000000000000000000", // CHECK TPL
            "/elements/hosts/00000000000000000000000000000233", // Create diff
            "/elements/hosts/00000000000000000000000000000233", // Unused cause save
            "/elements/working_area/hosts?filter=type:\"Différence\"", // Test popup diff
            "/apply", // Test preprod
            "/elements/working_area/hosts/00000000000000000000000000000233", // Test diff in element
            "/elements/working_area/hosts/00000000000000000000000000000233", // Accept diff
            "/elements/working_area/hosts/00000000000000000000000000000233", // submit to staging
            "/elements/hosts/00000000000000000000000000000233", // Unused cause save
            "/elements/elements?filter=working_area_status:\"Proposé\"", // Test popup Proposed
            "/elements/hosts/00000000000000000000000000000233", // Test propose in element
            "/elements/hosts/00000000000000000000000000000233", // Accept propose
            "/elements/hosts/00000000000000000000000000000233" // Unused cause save
        ],
        subject        : "notes_url"
    },
    "00234"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        port           : 7767,
        address        : [
            "/static/ui/index.html#/service_weather/00000000000000000000000000000001",
            "/service-weather/00000000000000000000000000000001",
            "/service-weather/00000000000000000000000000000001",
            "/service-weather/00000000000000000000000000000001",
            "/service-weather/00000000000000000000000000000001",
            "/service-weather/00000000000000000000000000000001",
            "/service-weather/00000000000000000000000000000001",
            "/service-weather/00000000000000000000000000000001",
            "/service-weather/00000000000000000000000000000001"
        ],
        subject        : "notes_url"
    },
    "00235"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        port           : [7766, 7766, 7766, 7767, 7767, 7767],
        address        : [
            "/main",
            "/elements/working_area/hosts",
            "/elements/working_area/hosts",
            "/static/ui/index.html",
            "/static/ui/index.html#/hosts/00000000000000000000000000000235/manage",
            "/static/ui/index.html#/hosts/00000000000000000000000000000235/checks"
        ],
        subject        : "notes_url"
    },
    "00236"   : {
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.CHARLIE,
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        port           : [7766, 7767, 7767, 7766, 7767, 7767],
        address        : ["/main", "/static/ui/index.html#/", "/static/ui/index.html#/list/", "/main", "/static/ui/index.html#/", "/static/ui/index.html#/list/"],
        subject        : "add_to_favorite"
    },
    "00237"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        address        : ["/main", "/main"],
        subject        : "secretsdump.py"
    },
    "00238"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        address        : ["/main", "/main", "/main"],
        subject        : "test admin si's permissions on apply page"
    },
    "00239"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        address        : [
            "/elements/hosts/00000000000000000000000000000001",
            "/elements/hosts/00000000000000000000000000000001",
            "/elements/hosts/00000000000000000000000000000001"
        ],
        subject        : "Test result try check long output is not in short output"
    },
    "00243"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : [7766,7766,7766,7766,7766,7766,7767,
                          7767,7766,7766],
        address        : [
            "/elements/contacts/35000000000000000000000000000000",
            "/elements/contacts/35000000000000000000000000000000",
            "/apply",
            "/apply",
            "/login",
            "/login",
            "/static/ui/index.html#/",
            "/static/ui/index.html#/",
            "/elements/contacts/35000000000000000000000000000000",
            "/apply",
            "/apply",
        ],
        subject        : "Test if the duration of the authentification works SEF-10949"
    },
    "00242"   : {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        version_minimum: SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO,
        port           : 7766,
        address        : [
            "/elements/hosts/00000000000000000000000000000242",
            "/elements/hosts/00100000000000000000000000000242",
            "/elements/hosts/00200000000000000000000000000242",
            "/elements/hosts/00300000000000000000000000000242"
        ],
        subject        : "Test result try check result threshold for pack Switch"
    },
    "delete_1": {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/elements?filter=sources:test_auto&shinken_test_auto=delete1"
    },
    "delete_2": {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/elements/working_area/hosts?filter=sources:test_auto~save_in_staging:1&shinken_test_auto=delete2"
    },
    "linker_1": {
        testable_status: SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.RUNNING,
        address        : "/sources/" + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER + "?tab=tab-synchronizers-list&shinken_test_auto=linker1"
    }
};
